@@ -2,7 +2,7 @@ use v5.10;
 use strict;
 use warnings;
 package Tie::Scalar::Callback;
-$Tie::Scalar::Callback::VERSION = '0.061';
+$Tie::Scalar::Callback::VERSION = '0.062';
 use parent 'Tie::Scalar';
 use Carp qw(carp);
 
@@ -41,7 +41,7 @@ Tie::Scalar::Callback - a tied scalar which executes a callback everytime it is
 
 =head1 VERSION
 
-version 0.061
+version 0.062
 
 =head1 SYNOPSIS
 
@@ -91,7 +91,7 @@ L<Tie::Scalar::Ratio|https://metacpan.org/pod/Tie::Scalar::Ratio>
 
 =head1 AUTHOR
 
-['David Farrell <dfarrell@cpan.org>', 'brian d foy <bdfoy@cpan.org>']
+David Farrell <dfarrell@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
